@@ -2,13 +2,15 @@ import os
 import re
 import math
 
+import cPickle as pickle
+
 from celery import task,chord,group,chain
 from celery.signals import task_success
 from celery.utils.log import get_task_logger
 
 from django.conf import settings
 
-from ngrams.utils import in_trigram_context_entropy
+#from ngrams.utils import in_trigram_context_entropy
 
 from .models import *
 from .managers import BulkManager,chunks
@@ -264,38 +266,49 @@ def doStringSelect(form):
                 continue
             comps.append((q,s))
     print(len(comps))
-    c2 = chord(group([analyze_block.s(x) for x in chunks(comps,1000)]))(combine_results.s())
+    count = 0
+    for x in chunks(comps,100):
+        count += 1
+        with open(os.path.join(settings.TEMP_DIR,'celex-strings-%d.txt'%count),'w') as f:
+            pickle.dump(x,f)
+
+@task()
+def doNGramAnalysis():
+    files = sorted(filter(lambda x: x.startswith('celex-strings'),os.listdir(settings.TEMP_DIR)))
+    c2 = chord(group([analyze_block.s(x) for x in chunks(files,50)]))(combine_results.s())
     c2.get()
 
 @task()
-def analyze_block(comp):
+def analyze_block(files):
     output = []
-    for c in comp:
-        q = c[0]
-        s = c[1]
-        t_one = str(q.transcriptions.all()[0])
-        o_one = q.orthographies.all()
-        t_two = str(s.transcriptions.all()[0])
-        o_two = s.orthographies.all()
-        phon_dist = str(get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two)))
-        #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
-        #    if t_one != t_two:
-        #        continue
-        #    phon_dist = "homophone"
-        #else:
-        #    phon_dist = "neighbour"
-        in_context_entropy = str(in_trigram_context_entropy(o_one,o_two))
-        c_one = str(q.lemma.category.label)
-        c_two = str(s.lemma.category.label)
-        f_one = str(q.frequency)
-        f_two = str(s.frequency)
-        L_one = str(q.lemma.label)
-        L_two = str(s.lemma.label)
-        LFreq_one = str(q.lemma.frequency)
-        LFreq_two = str(s.lemma.frequency)
-        output.append([':'.join(map(str,o_one)),':'.join(map(str,o_two)),t_one,t_two,
-                                c_one,c_two,f_one,f_two,L_one,L_two,
-                                LFreq_one,LFreq_two,phon_dist,in_context_entropy])
+    for f in files:
+        comp = pickle.load(os.path.join(settings.TEMP_DIR,f))
+        for c in comp:
+            q = c[0]
+            s = c[1]
+            t_one = str(q.transcriptions.all()[0])
+            o_one = q.orthographies.all()
+            t_two = str(s.transcriptions.all()[0])
+            o_two = s.orthographies.all()
+            phon_dist = str(get_phone_dist(re.sub('\'','',t_one),re.sub('\'','',t_two)))
+            #if not is_neighbour(re.sub('\'','',t_one),re.sub('\'','',t_two)):
+            #    if t_one != t_two:
+            #        continue
+            #    phon_dist = "homophone"
+            #else:
+            #    phon_dist = "neighbour"
+            in_context_entropy = str(in_trigram_context_entropy(o_one,o_two))
+            c_one = str(q.lemma.category.label)
+            c_two = str(s.lemma.category.label)
+            f_one = str(q.frequency)
+            f_two = str(s.frequency)
+            L_one = str(q.lemma.label)
+            L_two = str(s.lemma.label)
+            LFreq_one = str(q.lemma.frequency)
+            LFreq_two = str(s.lemma.frequency)
+            output.append([':'.join(map(str,o_one)),':'.join(map(str,o_two)),t_one,t_two,
+                                    c_one,c_two,f_one,f_two,L_one,L_two,
+                                    LFreq_one,LFreq_two,phon_dist,in_context_entropy])
     return output
 
 @task()
